#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
#  PLOT.PY
#
#    Steven Hale
#    2015 August 13
#    Birmingham, UK
#
#  This Python module configures some standard plot settings.
#

########################################################################
########################################################################
########################################################################

import matplotlib as mpl
import matplotlib.pyplot as plt

########################################################################

def setlatex():

    # Use LaTeX for the labels.
    mpl.rcParams['text.usetex'] = True
    mpl.rcParams['font.family'] = 'serif'
    # Use the LaTeX default Computer Modern fonts by clearing the list
    # for font.serif.
    mpl.rcParams['font.serif']  = []

def confax(ax, lr = 'left'):

    if lr == 'left':
        ax.spines["top"].set_visible(False)  
        ax.spines["right"].set_visible(False)  
        ax.xaxis.set_ticks_position('bottom')
        ax.yaxis.set_ticks_position('left')
        ax.tick_params(axis='both', which='both', direction='out')
    else:
        ax.spines["top"].set_visible(False)  
        ax.spines["bottom"].set_visible(False)  
        ax.spines["left"].set_visible(False)  
        ax.xaxis.set_ticks_position('none')
        ax.yaxis.set_ticks_position('right')
        ax.tick_params(axis='both', which='both', direction='out')
    return ax

def confaxright(ax):

    ax.spines["top"].set_visible(False)  
    ax.spines["left"].set_visible(False)  
    ax.spines["right"].set_visible(False)  
    plt.setp(ax.get_yticklabels(), visible=False)
    ax.xaxis.set_ticks_position('bottom')
    ax.yaxis.set_ticks_position('none')
    ax.tick_params(axis='both', which='both', direction='out')
    return ax

def confaxtop(ax):

    ax.spines["top"].set_visible(False)  
    ax.spines["bottom"].set_visible(False)  
    ax.spines["right"].set_visible(False)  
    plt.setp(ax.get_xticklabels(), visible=False)
    ax.xaxis.set_ticks_position('none')
    ax.yaxis.set_ticks_position('left')
    ax.tick_params(axis='both', which='both', direction='out')
    return ax

def confaxnone(ax):

    ax.spines["top"].set_visible(False)  
    ax.spines["bottom"].set_visible(False)  
    ax.spines["left"].set_visible(False)  
    ax.spines["right"].set_visible(False)  
    plt.setp(ax.get_xticklabels(), visible=False)
    plt.setp(ax.get_yticklabels(), visible=False)
    ax.xaxis.set_ticks_position('none')
    ax.yaxis.set_ticks_position('none')
    ax.tick_params(axis='both', which='both', direction='out')
    return ax

def setFonts(fontSize = 12):
    
    plt.rc('font',   size      = fontSize) # controls default text sizes
    plt.rc('axes',   titlesize = fontSize) # fontsize of the axes title
    plt.rc('axes',   labelsize = fontSize) # fontsize of the x any y labels
    plt.rc('xtick',  labelsize = fontSize) # fontsize of the tick labels
    plt.rc('ytick',  labelsize = fontSize) # fontsize of the tick labels
    plt.rc('legend', fontsize  = fontSize) # legend fontsize
    plt.rc('figure', titlesize = fontSize) # # size of the figure title

    return plt
    
def canvas(size = 'normal', w=None, h=None, aspect=None):

    # figsize is w,h tuple in inches

    # \usepackage{layouts}
    # textwidth:  \printinunitsof{in}\prntlen{\textwidth}
    # linewidth:  \printinunitsof{in}\prntlen{\linewidth}
    # textheight: \printinunitsof{in}\prntlen{\textheight}
    #
    # textwidth:  6.30045in
    # linewidth:  6.30045in
    # textheight: 8.40527in

    textWidth = 6.3
    textHeight = 8.4
    
    if size == 'normal':
        # Full width at 16:9 aspect ratio.
        xsize = textWidth
        ysize = xsize / (16/9)
    elif size == 'twocol':
        # Half width at 4:3 aspect ratio.
        xsize = 0.98 * (textWidth / 2)
        ysize = xsize / (4/3)
    elif size == 'full':
        # Full page figure.
        xsize = textWidth
        ysize = textHeight
    elif size == 'narrow':
        # Full width at 16:4.5 aspect ratio.
        xsize = textWidth
        ysize = xsize / (16/4.5)
    elif size == 'square':
        # Full width at 1:1 aspect ratio.
        xsize = textWidth
        ysize = xsize
    elif size == 'aas_onecol':
        # AAS uses the following sizes:
        #   textwidth: 7.1014in
        #   linewidth: 7.1014in  (one column)
        #   linewidth: 3.35289in (two column)
        #  textheight: 9.0971in
        #
        # \plotone = 0.85\linewidth
        # \plottwo = 0.425\linewidth
        textWidth = 7
        xsize = 0.85 * textWidth
        ysize = xsize / (16/9)
    elif size == 'aas_twocol':
        textWidth = 7
        xsize = 0.425 * textWidth
        ysize = xsize / (16/9)
    else:
        raise ValueError('Unrecognised image size.')

    if w is not None:
        xsize = w
    
    if h is not None:
        ysize = h

    if aspect is not None:
        ysize = xsize / aspect
        
    return plt.figure(figsize=(xsize, ysize))

def save(fig, sFilespec):
    fig.savefig(sFilespec, dpi=300, bbox_inches='tight', pad_inches=0.03)

########################################################################
